'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.bollingerBandsArray = undefined;

var _binaryUtils = require('binary-utils');

var _math = require('./math');

var _simpleMovingAverage = require('./simpleMovingAverage');

var _simpleMovingAverage2 = _interopRequireDefault(_simpleMovingAverage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var bollingerBands = function bollingerBands(data, config) {
    var _config$periods = config.periods,
        periods = _config$periods === undefined ? 20 : _config$periods,
        field = config.field,
        _config$stdDevUp = config.stdDevUp,
        stdDevUp = _config$stdDevUp === undefined ? 2 : _config$stdDevUp,
        _config$stdDevDown = config.stdDevDown,
        stdDevDown = _config$stdDevDown === undefined ? 2 : _config$stdDevDown,
        _config$pipSize = config.pipSize,
        pipSize = _config$pipSize === undefined ? 2 : _config$pipSize;

    var vals = (0, _math.takeLast)(data, periods, field);
    var middle = (0, _simpleMovingAverage2.default)(vals, { periods: periods });
    var stdDev = (0, _math.stddev)(vals);
    var upper = middle + stdDev * stdDevUp;
    var lower = middle - stdDev * stdDevDown;

    return [+middle.toFixed(pipSize), +upper.toFixed(pipSize), +lower.toFixed(pipSize)];
};

var bollingerBandsArray = exports.bollingerBandsArray = function bollingerBandsArray(data, config) {
    var periods = config.periods;

    return (0, _binaryUtils.sequence)(data.length - periods + 1).map(function (x, i) {
        return bollingerBands(data.slice(i, i + periods), config);
    });
};

exports.default = bollingerBands;